@@ -7,12 +7,12 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-12-01'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.041'; # VERSION
+our $VERSION = '0.042'; # VERSION
 
 sub meta {
     +{
         v => 1,
-        summary => 'Repeat a string a number of times',
+        summary => '"this" Perl distribution name',
         description => <<'_',
 
 See <pm:App::ThisDist>'s `this_mod()` for more details on how "this module" is
@@ -58,7 +58,7 @@ Data::Sah::Value::perl::Perl::this_dist
 
 =head1 VERSION
 
-This document describes version 0.041 of Data::Sah::Value::perl::Perl::this_dist (from Perl distribution Sah-Schemas-Perl), released on 2021-12-01.
+This document describes version 0.042 of Data::Sah::Value::perl::Perl::this_dist (from Perl distribution Sah-Schemas-Perl), released on 2021-12-01.
 
 =head1 DESCRIPTION
 
